Method: MultiRubyRunner#execute_command_in_directory
- Defined in:
- lib/multi_ruby_runner.rb
#execute_command_in_directory(command_string, directory, options = {}) ⇒ String, ...
Executes a command in a directory. Command will be executed in the ruby environment specified in .ruby-version file in directory. Returns stdout in the blocking form and pid of child process in the non-blocking form.
27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/multi_ruby_runner.rb', line 27 def execute_command_in_directory(command_string, directory, = {}) shell_path = ENV['SHELL'] || '/bin/bash' = { blocking: true, shell_invocation: "#{ shell_path } -c", }.merge() process_args = ruby_version_manager.compute_process_args( command_string, directory, ) execute_command(process_args) end |